@@ -1,5 +1,8 @@
 from functools import wraps
+from functools import cache as optimize
+import time
 from time import perf_counter
+import sys
 
 def isfloat(x):
     try:
@@ -40,3 +43,12 @@ def get_time(func):
         print('Durata:', total_time, 'secondi.')
 
     return wrapper
+
+def setup():
+    sys.setrecursionlimit(1000000000)
+    return "Setup Done."
+
+
+print(setup())
+print(sys.getrecursionlimit())
+
